@@ -81,6 +81,7 @@ static int fbdev_randr12_preinit(ScrnInfoPtr screen);
 static void fbdev_enable_fb_access(int scrn_index, Bool enable);
 static void fbdev_property_callback(CallbackListPtr * pcbl, pointer unused,
 				    pointer calldata);
+static int fbdev_crtc_rotate(xf86CrtcPtr crtc, int rotation);
 
 /* -------------------------------------------------------------------- */
 
@@ -541,6 +542,12 @@ static Bool FBDevCloseScreen(int scrnIndex, ScreenPtr pScreen)
 	ScrnInfoPtr pScrn = xf86Screens[scrnIndex];
 	FBDevPtr fPtr = FBDEVPTR(pScrn);
 
+        /* Rotate back to landscape to prevent Nokia logo from being
+         * messed up if shutdown from portrait mode. Do this before
+         * EXA_Fini on purpose, because pixmap hash table is released
+         * there but used on rotation. */
+	fbdev_crtc_rotate (fPtr->crtc_lcd, RR_Rotate_0);
+
 	EXA_Fini(pScreen);
 
 	fbdev_fini_video (pScreen);
